.. _research:

Research and contribution
=========================

Research
--------

If you are doing research using PennyLane, please cite the PennyLane paper:

    Ville Bergholm, Josh Izaac, Maria Schuld, Christian Gogolin, Carsten Blank, Keri McKiernan, and Nathan Killoran.
    *PennyLane: Automatic differentiation of hybrid quantum-classical computations.* 2018. `arXiv:1811.04968 <https://arxiv.org/abs/1811.04968>`_

We are always open for collaboration; you can contact us at research@xanadu.ai.

Support
-------

- **Source Code:** https://github.com/XanaduAI/pennylane
- **Issue Tracker:** https://github.com/XanaduAI/pennylane/issues

If you are having issues, please let us know by posting the problem on our Github issue tracker.

To chat directly with the team designing and building PennyLane, as well as members of our community — ranging from quantum machine learning researchers, to students, to those just interested in being a part of a rapidly growing industry — you can join our `PennyLane discussion forum <https://discuss.pennylane.ai>`_.

Available categories include:

* `PennyLane Feedback <https://discuss.pennylane.ai/c/pennylane-feedback>`_: For general discussion regarding PennyLane, including feature requests
* `PennyLane Help <https://discuss.pennylane.ai/c/pennylane-help>`_: For help and advice using PennyLane
* `PennyLane Development <https://discuss.pennylane.ai/c/pennylane-development>`_: For discussion of PennyLane development
* `PennyLane Plugins <https://discuss.pennylane.ai/c/pennylane-plugins>`_: For discussion of the available PennyLane plugins, and plugin development
* `Xanadu Software <https://discuss.pennylane.ai/c/xanadu-software>`_: For discussion relating to other Xanadu software projects, including `StrawberryFields <https://github.com/xanaduai/strawberryfields>`_, `QMLT <https://github.com/xanaduai/hafnian>`_, `Hafnian <https://github.com/xanaduai/hafnian>`_, and `OpenBoson <https://github.com/xanaduai/sfopenboson>`_.

Sometimes, it might take us a couple of hours to reply - please be patient!

Contribution
------------

We encourage contributions — simply fork the PennyLane repository, and then make a
`pull request <https://help.github.com/articles/about-pull-requests/>`_ containing your contribution. All contributers to PennyLane will be listed as authors on the releases. **All users who contribute significantly to the code (new plugins, new functionality, etc.) will be listed on the PennyLane arXiv paper.**

We also encourage bug reports, suggestions for new features and enhancements, and even links to cool projects or applications built on PennyLane.

**Update**: big announcement! We're excited to launch the Xanadu Quantum Software Competition, with prizes of up
to $1000 on offer. Submissions close 30th August 2019 — so no excuse not to submit your PennyLane
contribution, whether its an informative Jupyter notebook, PennyLane plugin, or a cool research result.

See the `competition website <https://pennylane.ai/competition>`_ or our
`blog post <https://medium.com/xanaduai/announcing-the-xanadu-quantum-software-competition-bdcd3d6d53a9>`_ for more.

For the full contributing guidelines, please see our `contributions page <https://github.com/XanaduAI/pennylane/blob/master/.github/CONTRIBUTING.md>`_
for more details.
